Struct sqlness::ConfigBuilder

source ·
pub struct ConfigBuilder { /* private fields */ }
Builder for Config.

Implementations

source

impl ConfigBuilder

source

pub fn case_dir(&mut self, value: String) -> &mut Self

source

pub fn test_case_extension(&mut self, value: String) -> &mut Self

Default value: sql

source

pub fn result_extension(&mut self, value: String) -> &mut Self

Default value: result

source

pub fn interceptor_prefix(&mut self, value: String) -> &mut Self

Default value: -- SQLNESS

source

pub fn env_config_file(&mut self, value: String) -> &mut Self

Default value: config.toml

source

pub fn fail_fast(&mut self, value: bool) -> &mut Self

Fail this run as soon as one case fails if true

source

pub fn test_filter(&mut self, value: String) -> &mut Self

If specified, only run cases containing this string in their names.

Whether follow symbolic links when searching test case files. Defaults to “false” (not follow symbolic links).

source

pub fn build(&self) -> Result<Config, ConfigBuilderError>

Builds a new Config.

Errors

If a required field has not been initialized.